# Data analysis script for Nettle and Fraser 'Hunger affects cooperation in a Public Goods Game but not an Ultimatum Game'
# Daniel Nettle / Sam Fraser
# Version of Jan 2020

###Head#######
# Packages
library(dplyr)
library(ggplot2)
library(psych)
library(lmerTest)
library(cowplot)
library(tidyr)
library(reshape2)
library(metafor)
theme_set(theme_bw())

# Get experiment 1 data
d1<-read.csv("Experiment_1.csv")
d1$QuestionsCorrect=8*d1$QuestionsCorrect
d1$Condition.Name="Breakfast"
d1$Condition.Name[d1$Condition==0]="No Breakfast"
d1$Condition.Name=factor(d1$Condition.Name)

# Get experiment 2 data
d2=read.csv("Experiment_2.csv")
d2$UniqueID=factor(paste(d2$Experiment, d2$Participant.Number))
d2$Sample="Sample 1"
d2$Sample[d2$Experiment=="Replication"]="Sample 2"
d2$Previous.Rounds=d2$Round-1
ph=subset(d2, Punishment.Round=="Y")
ph$Sent.Punishment=(as.numeric(as.character(ph$Punishment.Sent))>0)
ph$MCO = (ph$Group.Contribution-ph$Contribution)/3
# t is the latency data for experiment 2
t=read.csv("Experiment_2_time.csv")
t$Condition.Name="Breakfast"
t$Condition.Name[t$Condition==0]="No breakfast"
t$Round[t$Trial.Number<11]=t$Trial.Number[t$Trial.Number<11]
t$Round[t$Trial.Number>10]=t$Trial.Number[t$Trial.Number>10]-10
t$Previous.Rounds=t$Round-1

#### Experiment 1 ####
# Descriptives
xtabs(~d1$Gender)
xtabs(~d1$Condition)

###Manipulation check#####
table(d1$BreakfastToday, d1$Condition.Name)
prop.table(table(d1$BreakfastToday, d1$Condition.Name), margin=2)
summary(lm(HowHungry~Condition.Name, data=d1))
describeBy(d1$HowHungry, d1$Condition.Name)
t.test(d1$HowHungry ~ d1$Condition.Name, var.equal=T)
describeBy(d1$ProposedAmount, d1$ProposerFirst)
describeBy(d1$LowestAcceptable, d1$ProposerFirst)
cor.test(d1$ProposedAmount, d1$LowestAcceptable)

### Experimental effects #####
# Proposer
summary(lm(ProposedAmount~Condition.Name, data=d1))
describeBy(d1$ProposedAmount, d1$Condition.Name)
# Dichotomous outcome
d1$Proposer.Cut=cut(d1$ProposedAmount, c(-0.5, 4.75, 10))
table(d1$ProposedAmount)/106
table(d1$Proposer.Cut)
table(d1$Proposer.Cut, d1$Condition.Name)
prop.table(table(d1$Proposer.Cut, d1$Condition.Name), margin=2)
chisq.test(d1$Proposer.Cut, d1$Condition.Name)

# Responder role
# Lowest acceptable
summary(lm(LowestAcceptable~Condition.Name, data=d1))
describeBy(d1$LowestAcceptable, d1$Condition.Name)
# Dichotomise into those who demanded at least 50% and those who did not
d1$Lowestcut=cut(d1$LowestAcceptable, c(-0.5, 4.75, 10))
prop.table(table(d1$Lowestcut, d1$Condition.Name), margin=2)
chisq.test(d1$Lowestcut, d1$Condition.Name)

####Figure 1a#####
# Make summary by condition and amount
fig1.dat=summarise(group_by(d1, ProposedAmount, Condition.Name), n=n())
fig1.dat$key=paste(fig1.dat$Condition.Name, fig1.dat$ProposedAmount)
fig1.dat$key
# Make data frame of possible contributions
Amount=rep(seq(0, 10, by=0.5), times=2)
Condition=c(rep("Breakfast", times=21), rep("No Breakfast", times=21))
x=data.frame(Amount, Condition)
x$key=paste(x$Condition, x$Amount)
# Merge
fig1.dat=merge(x, fig1.dat, by="key", all.x=T)
fig1.dat$n[is.na(fig1.dat$n)]=0
fig1.dat$prop=fig1.dat$n/60
fig1.dat$prop[fig1.dat$Condition=="No Breakfast"]=fig1.dat$n[fig1.dat$Condition=="No Breakfast"]/46
# Now make figure
fig1=ggplot(fig1.dat, aes(x=Amount, y=prop, fill=Condition)) + 
  geom_bar(stat="identity", position=position_dodge()) + 
  scale_fill_manual(values=c("blue", "red")) + 
  guides(fill=FALSE) + 
  ylab("Proportion of proposers") + 
  xlab("Amount proposed")
fig1

#Lowest acceptable offer (fig1b)
# Make summary by condition and amount
fig1b.dat=summarise(group_by(d1, LowestAcceptable, Condition.Name), n=n())
fig1b.dat$key=paste(fig1b.dat$Condition.Name, fig1b.dat$LowestAcceptable)
# Make data frame of possible acceptables
Lowest=rep(seq(0, 10, by=0.5), times=2)
Condition=c(rep("Breakfast", times=21), rep("No Breakfast", times=21))
xb=data.frame(Lowest, Condition)
xb$key=paste(xb$Condition, xb$Lowest)
# Merge
fig1b.dat=merge(xb, fig1b.dat, by="key", all.x=T)
fig1b.dat$n[is.na(fig1b.dat$n)]=0
fig1b.dat$prop=fig1b.dat$n/60
fig1b.dat$prop[fig1b.dat$Condition=="No Breakfast"]=fig1b.dat$n[fig1b.dat$Condition=="No Breakfast"]/46
# Now make figure
fig1b=ggplot(fig1b.dat, aes(x=Lowest, y=prop, fill=Condition)) + 
  geom_bar(stat="identity", position=position_dodge()) + 
  scale_fill_manual(values=c("blue", "red")) + 
  ylab("Proportion of responders") + 
  xlab("Minumum acceptable") + 
  theme(legend.position = c(0.825, 0.5))
fig1b

png("fig1.png", res=300, , width=10, height=4, units="in")
plot_grid(fig1, fig1b, labels=c("A", "B"))
dev.off()


##### Decision latencies####
summary(lm(log(TimeProposer)~Condition.Name, data=d1))
describeBy(log(d1$TimeProposer), d1$Condition.Name)
summary(lm(log(TimeResponder)~Condition.Name, data=d1))
describeBy(log(d1$TimeResponder), d1$Condition.Name)
cor.test(log(d1$TimeProposer), d1$ProposedAmount)
cor.test(log(d1$TimeResponder), d1$LowestAcceptable)

###Cognitive reflection task#####
summary(lm(d1$QuestionsCorrect~d1$Condition.Name))
describeBy(d1$QuestionsCorrect, d1$Condition.Name)
summary(lm(log(d1$TotalQuestionTime)~d1$Condition.Name))
describeBy(log(d1$TotalQuestionTime), d1$Condition.Name)
cor.test(d1$QuestionsCorrect, log(d1$TotalQuestionTime))
cor.test(d1$QuestionsCorrect, d1$ProposedAmount)
cor.test(d1$QuestionsCorrect, d1$LowestAcceptable)

###Using hunger instead of treatment#####
# Proposer
summary(lm(ProposedAmount~HowHungry, data=d1))
summary(lm(LowestAcceptable~HowHungry, data=d1))

### Experiment 2#####
###Manipulation checks####
# Overall
mc.data=subset(d2, Round==1 & Punishment.Round=="N")
table(mc.data$BreakfastToday, mc.data$Condition.Name)
prop.table(table(mc.data$BreakfastToday, mc.data$Condition.Name), margin=2)
t.test(mc.data$HowHungry~mc.data$Condition.Name, var.equal=T)
describeBy(mc.data$HowHungry, mc.data$Condition.Name)

# Sample 1 only
mc.data.s1=subset(d2, Round==1 & Punishment.Round=="N" & Sample=="Sample 1")
table(mc.data.s1$BreakfastToday, mc.data.s1$Condition.Name)
prop.table(table(mc.data.s1$BreakfastToday, mc.data.s1$Condition.Name), margin=2)
t.test(mc.data.s1$HowHungry~mc.data.s1$Condition.Name, var.equal=T)
# Sample 2 only 
mc.data.s2=subset(d2, Round==1 & Punishment.Round=="N" & Sample=="Sample 2")
table(mc.data.s2$BreakfastToday, mc.data.s2$Condition.Name)
prop.table(table(mc.data.s2$BreakfastToday, mc.data.s2$Condition.Name), margin=2)
t.test(mc.data.s2$HowHungry~mc.data.s2$Condition.Name, var.equal=T)

##Comprehension questions#####
comp.data=summarise(group_by(d2, UniqueID), Condition.Name=last(Condition.Name), Sample=last(Sample), comp1=6*mean(Non.Punishment.Questions.Correct), comp2 = 2*mean(Punishment.Questions.Correct), 
                    check1=sd(Non.Punishment.Questions.Correct), check2 = sd(Punishment.Questions.Correct),)
# Comparison by condition
psych::describeBy(comp.data$comp1, comp.data$Condition.Name)
t.test(comp.data$comp1~comp.data$Condition.Name, var.equal=T)
psych::describeBy(comp.data$comp2, comp.data$Condition.Name)
t.test(comp.data$comp2~comp.data$Condition.Name, var.equal=T)
# Comparison by sample
psych::describeBy(comp.data$comp1, comp.data$Sample)
t.test(comp.data$comp1~comp.data$Sample, var.equal=T)
psych::describeBy(comp.data$comp2, comp.data$Sample)
t.test(comp.data$comp2~comp.data$Sample, var.equal=T)
# Effect of comphrension questions correct on contribution
mcomp=lmer(Contribution~Previous.Rounds*Punishment.Round + I(6*Non.Punishment.Questions.Correct) + (1|UniqueGroup/UniqueID), data=d2, REML=F)
summary(mcomp)
# Effect of comprehension of punishment on decision to punish
mpcomp=glmer(Sent.Punishment ~    
           scale(MCO) + scale(Punishment.Questions.Correct) +  
           (1|UniqueGroup/UniqueID), data=ph, family=binomial, na.action="na.fail")
summary(mpcomp)

###Sample 1 analysis (model 1)#####
m1=lmer(Contribution~Previous.Rounds*Punishment.Round*Condition.Name + (1|UniqueGroup/UniqueID), data=subset(d2, Sample=="Sample 1"), REML=F)
summary(m1)
m1n=lmer(Contribution~Previous.Rounds*Punishment.Round + (1|UniqueGroup/UniqueID), data=subset(d2, Sample=="Sample 1"), REML=F)
summary(m1n)
anova(m1, m1n)

###Sample 2 analysis (model 2)#####
m2=lmer(Contribution~Previous.Rounds*Punishment.Round*Condition.Name + (1|UniqueGroup/UniqueID), data=subset(d2, Sample=="Sample 2"), REML=F)
summary(m2)
m2n=lmer(Contribution~Previous.Rounds*Punishment.Round + (1|UniqueGroup/UniqueID), data=subset(d2, Sample=="Sample 2"), REML=F)
summary(m2n)
anova(m2, m2n)

###Whole sample analysis (model 3)#####
m3=lmer(Contribution~Previous.Rounds*Punishment.Round*Condition.Name + (1|UniqueGroup/UniqueID), data=d2, REML=F)
summary(m3)
describeBy(d2$Contribution[d2$Round==1], paste(d2$Condition.Name[d2$Round==1], d2$Punishment.Round[d2$Round==1]))
# What happens if you add in number of comprehension questions correct?
m3b=lmer(Contribution~Previous.Rounds*Punishment.Round*Condition.Name + Non.Punishment.Questions.Correct + (1|UniqueGroup/UniqueID), data=d2, REML=F)
summary(m3b)

###Figure 2a: Forest plot######
bs=c(summary(m1)$coefficients[4, 1], 
     summary(m2)$coefficients[4, 1], 
     summary(m3)$coefficients[4, 1], 
     summary(m1)$coefficients[6, 1], 
     summary(m2)$coefficients[6, 1], 
     summary(m3)$coefficients[6, 1], 
     summary(m1)$coefficients[7, 1], 
     summary(m2)$coefficients[7, 1], 
     summary(m3)$coefficients[7, 1])
ses=c(summary(m1)$coefficients[4, 2], 
     summary(m2)$coefficients[4, 2], 
     summary(m3)$coefficients[4, 2], 
     summary(m1)$coefficients[6, 2], 
     summary(m2)$coefficients[6, 2], 
     summary(m3)$coefficients[6, 2], 
     summary(m1)$coefficients[7, 2], 
     summary(m2)$coefficients[7, 2], 
     summary(m3)$coefficients[7, 2])
slab=c("Condition, sample 1", "Condition, sample 2", "Condition, samples pooled", "Condition*round, sample 1", "Condition*round, sample 2", "Condition*round, samples pooled","Condition*game, sample 1", "Condition*game, sample 2", "Condition*game, samples pooled")
win.metafile("fig2a.wmf", width=8, height=4)
forest.default(x=bs, sei=ses, slab=slab, psize=1, xlab="Effect size", rows=c(9, 8, 7, 5, 4, 3, 1, 0, -1), ylim=c(-2, 12), alim=c(-6, 6))
dev.off()

####Figure 2b #####
round.summarya=summarise(group_by(d2, Punishment.Round, Round, Condition.Name, UniqueGroup), 
                          Contribution=mean(Contribution))
round.summary=summarise(group_by(round.summarya, Punishment.Round, Round, Condition.Name), 
                          Mean.Contribution=mean(Contribution), se=describe(Contribution)$se)
round.summary$Game="Punishment"
round.summary$Game[round.summary$Punishment.Round=="N"]="No punishment"
fig2b=ggplot(round.summary, aes(x=factor(Round), y=Mean.Contribution, colour=Condition.Name)) + 
  geom_point() + 
  geom_line(aes(x=Round)) + 
  coord_cartesian(ylim=c(0, 20)) + 
  geom_errorbar(aes(ymax=Mean.Contribution+se, ymin=Mean.Contribution-se), width=0.1) + 
  xlab("Round") + 
  ylab("Mean Contribution") + 
  scale_colour_manual(name="Condition", values=c("blue", "red")) + 
  facet_wrap(~ Game)  +
  theme(legend.position="bottom")
fig2b
win.metafile("fig2b.wmf", width=7, height=4)
fig2b
dev.off()


###Response to punishment (model 4)#####
m4=lmer(Contribution~ Lagged.Contribution*Condition.Name*Lagged.Punished + (1|UniqueGroup/UniqueID), data=subset(d2, Punishment.Round=="Y" & Round>1), REML=F)
options(scipen=999)
summary(m4)

###Decision to punish (model 5)####
ph=subset(d2, Punishment.Round=="Y")
ph$Sent.Punishment=(as.numeric(as.character(ph$Punishment.Sent))>0)
table(ph$Sent.Punishment, ph$Condition.Name)
colSums(table(ph$Sent.Punishment, ph$Condition.Name))
prop.table(table(ph$Sent.Punishment, ph$Condition.Name), margin=2)
chisq.test(ph$Sent.Punishment, ph$Condition.Name)
ph$MCO = (ph$Group.Contribution-ph$Contribution)/3
m5=glmer(Sent.Punishment ~    
                scale(MCO)*Condition.Name +  
                (1|UniqueGroup/UniqueID), data=ph, family=binomial, na.action="na.fail")
summary(m5)
# Does comprehension affect this?
m5b=glmer(Sent.Punishment ~    
           scale(MCO)*Condition.Name +  Punishment.Questions.Correct + 
           (1|UniqueGroup/UniqueID), data=ph, family=binomial, na.action="na.fail")
summary(m5b)

###Figure 3 (punishment)######
#Fig 3a: The difference made by punishment
fig3a.dat.1=summarise(group_by(d2, UniqueGroup, Punishment.Round, Round, Condition.Name), mean.cont=mean(Contribution))
fig3a.dat.2=spread(fig3a.dat.1, key=Punishment.Round, value=mean.cont)
fig3a.dat.2$delta=fig3a.dat.2$Y-fig3a.dat.2$N
fig3a.dat=summarise(group_by(fig3a.dat.2, Condition.Name, Round), md=mean(delta), se=psych::describe(delta)$se)
fig3a=ggplot(fig3a.dat, aes(x=as.factor(Round), y=md, fill=Condition.Name)) + 
  geom_bar(stat="identity", position=position_dodge()) + 
  geom_errorbar(aes(ymin=md-se, ymax=md+se), position=position_dodge(0.9), width=0.25) + 
  scale_fill_manual(name="Condition", values=c("blue", "red")) + 
  ylab(expression(paste(Delta, " punishment"))) + 
  xlab("Round")
fig3a

# Fig3b: Response to punishment
ph$MCO.bin=cut(ph$MCO, c(-1, 5, 10, 15, 20))
ph$Lagged.Contribution.Bin=cut(ph$Lagged.Contribution, c(-1, 5, 10, 15, 20))
ph$Contribution.Change= ph$Contribution - ph$Lagged.Contribution
fig3b.dat=summarise(group_by(subset(ph, Lagged.Punished==1 & Round>1), Lagged.Contribution.Bin, Condition.Name), mean.cont.change=describe(Contribution.Change)$mean, se.cont.change=describe(Contribution.Change)$se)
fig3b.dat$midpoint=c(2.5, 2.5, 7.5, 7.5, 12.5, 12.5, 17.5, 17.5)
fig3b=ggplot(fig3b.dat, aes(x=midpoint, y=mean.cont.change, fill=Condition.Name)) + 
  geom_bar(position=position_dodge(), stat="identity") + 
  geom_errorbar(aes(ymin=mean.cont.change-se.cont.change, ymax=mean.cont.change+se.cont.change), position=position_dodge(5), width=1) +
  ylab("Change in contribution") + 
  xlab("Previous-round contribution") + 
  scale_fill_manual(name="Condition", values=c("blue", "red")) + 
  guides(fill=FALSE)
fig3b

# Fig 3c: Propensity to punish
fig3c.dat=summarise(group_by(ph, MCO.bin, Condition.Name), mean.cont=mean(Sent.Punishment))
fig3c.dat$midpoint=c(2.5, 2.5, 7.5, 7.5, 12.5, 12.5, 17.5, 17.5)
fig3c=ggplot(fig3c.dat, aes(x=midpoint, y=mean.cont, fill=Condition.Name)) + 
  geom_bar(stat="identity", position=position_dodge()) + 
  ylab("Probability of punishing") + 
  xlab("Mean contribution of others") + 
  scale_fill_manual(name="Condition", values=c("blue", "red"), labels=c("Breakfast", "No breakfast"))  
fig3c

png("fig3.png", width=8, height=8, units="in", res=300)
plot_grid(fig3a, plot_grid(fig3b, fig3c, rel_widths=c(0.43, 0.57), labels=c("B", "C")), nrow=2, ncol=1, labels=c("A", ""))
dev.off()

###Latency to make decisions (models 6 and 7)#####
# Latency to decide on a contribution
options(scipen=99)
m6 = lmer(log(TimeContribution)~Previous.Rounds*Punishment.Round*Condition.Name + (1|Group/Individual), data=t, REML=F)
summary(m6)
summarise(group_by(t, Round, Punishment.Round, Condition.Name), log.latency=mean(log(TimeContribution)), sd=describe(log(TimeContribution))$sd)

# Does latency to decide predict how much a person contributes?
cor.test(log(t$TimeContribution[t$Punishment.Round=="N" & t$Round==1]), t$Contribution[t$Punishment.Round=="N" & t$Round==1])

# What about latency to decide whether to punish (model 7)?
m7 = lmer(log(TimePunishment)~Previous.Rounds*Condition.Name + (1|Group/Individual), data=subset(t, Punishment.Round=="Y"), REML=F)
summary(m7)

###Figure 4 (latency to decide) #####
round.summary.time.1=summarise(group_by(t, Punishment.Round, Round, Condition.Name, Group), 
                          Time=mean(log(TimeContribution)))
round.summary.time=summarise(group_by(round.summary.time.1, Punishment.Round, Round, Condition.Name), 
                          Mean.Time=mean(Time), se=describe(Time)$se)
round.summary.time$Game="Punishment"
round.summary.time$Game[round.summary.time$Punishment.Round=="N"]="No punishment"

fig4=ggplot(round.summary.time, aes(x=factor(Round), y=Mean.Time, colour=Condition.Name)) + 
  geom_point() + 
  geom_line(aes(x=Round)) + 
  geom_errorbar(aes(ymax=Mean.Time+se, ymin=Mean.Time-se), width=0.1) + 
  xlab("Round") + 
  ylab("Mean decision time (log s)") +
  scale_colour_manual(name="Condition", values=c("blue", "red")) + 
  facet_wrap( ~ Game)  
png("fig4.png",res=300, units="in", width=8, height=4)
fig4
dev.off()

